Authable class abstract
- Implementers
Constructors
- Authable()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- password → AbstractPassword
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → AbstractUrl
-
no setter
- username → String
-
no setter
Methods
-
is_logged_in(
Online browser) → Future< bool> -
login(
Online browser) → Future< Online> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited