SapPurchaseRequestUrl class

For example. the code for Header release Service PR is ZPRS Header release Rental PR is ZPRR Header release Opex PR is ZPRO

Implemented types

Constructors

SapPurchaseRequestUrl(String code)
Header release Service PR is ZPRS Header release Rental PR is ZPRR Header release Opex PR is ZPRO
const

Properties

code String
Header release Service PR is ZPRS Header release Rental PR is ZPRR Header release Opex PR is ZPRO
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited